@@ -22,7 +22,9 @@
  
 #include "config.h"
 
+#include "galias.h"
 #include "glib.h"
+#include "gthreadinit.h"
 
 #if defined (__GNUC__)
 # if defined (G_ATOMIC_I486)
